**************************************************************************************************************************************
*** Lois, D. (2024): Zur Entwicklung der Kirchenmitgliedschaft in Deutschland - Eine aktualisierte Alters-Perioden-Kohortenanalyse ***
*** mit ALLBUS-Daten 1980-2021. Kölner Zeitschrift für Soziologie und Sozialpsychologie, 76, 2 *************************************** 
**************************************************************************************************************************************

version 17
clear all

* Adapt to your directory
global datapath "c:\Daten\" 
cd "c:\Daten\"


************************
*** Cumulation 82-18 ***
************************
use "$datapath\ZA5274_v1-0-0.dta", clear

* age, yborn, year, sex, rp01 (Kirchgang), rd01 (Konfession), eastwest, dh04 (Anzahl Haushaltspersonen), german (Design)

* cohort classification - separated for east/west

tab yborn
tab yborn if eastwest==2
tab yborn, nolabel
recode yborn (-9=.) (-7=.)

recode yborn (1890/1910=1) (1911/1915=2) (1916/1920=3) (1921/1925=4) (1926/1930=5) (1931/1935=6) (1936/1940=7) ///
(1941/1945=8) (1946/1950=9) (1951/1955=10) (1956/1960=11) (1961/1965=12) (1966/1970=13) (1971/1975=14) (1976/1980=15) (1981/1985=16) ///
(1986/1990=17) (1991/2010=18) (else=.), gen(coh5)

* West
recode yborn (1891/1921=1) (1922/1934=2) (1935/1945=3) (1946/1953=4) (1954/1964=5) (1965/1975=6) (1976/1990=7) (else=.) if eastwest==1, gen(cohort_w1)
recode yborn (1891/1921=1) (1922/1934=2) (1935/1945=3) (1946/1953=4) (1954/1964=5) (1965/1975=6) (1976/1990=7) (1991/2002=8) (else=.) if eastwest==1, gen(cohort_w2)

* East
recode yborn (1898/1930=1) (1931/1945=2) (1946/1960=3) (1961/1974=4) (1975/1990=5) if eastwest==2, gen(cohort_e1) 
recode yborn (1898/1930=1) (1931/1945=2) (1946/1960=3) (1961/1974=4) (1975/1990=5) (1991/2002=6) if eastwest==2, gen(cohort_e2) 

keep age yborn year sex rp01 rd01 eastwest dh04 german wghtpt wghtpew wghtptew wghtht wghthew wghthtew cohort_w1 cohort_w2 cohort_e1 cohort_e2 coh5

save "$datapath\c8218.dta", replace


*****************
*** GGSS 2021 ***
*****************

use "$datapath\ZA5280_v2-0-0.dta", clear
gen year = 2021 

* cohort classification - separated for east/west

tab yborn
tab yborn if eastwest==2
tab yborn, nolabel
recode yborn (-9=.) (-7=.)

recode yborn (1890/1910=1) (1911/1915=2) (1916/1920=3) (1921/1925=4) (1926/1930=5) (1931/1935=6) (1936/1940=7) ///
(1941/1945=8) (1946/1950=9) (1951/1955=10) (1956/1960=11) (1961/1965=12) (1966/1970=13) (1971/1975=14) (1976/1980=15) (1981/1985=16) ///
(1986/1990=17) (1991/2010=18) (else=.), gen(coh5)

* West
recode yborn (1891/1921=1) (1922/1934=2) (1935/1945=3) (1946/1953=4) (1954/1964=5) (1965/1975=6) (1976/1990=7) (else=.) ///
if eastwest==1, gen(cohort_w1)
recode yborn (1891/1921=1) (1922/1934=2) (1935/1945=3) (1946/1953=4) (1954/1964=5) (1965/1975=6) (1976/1990=7) (1991/2002=8) (else=.) ///
if eastwest==1, gen(cohort_w2)

* East
recode yborn (1898/1930=1) (1931/1945=2) (1946/1960=3) (1961/1974=4) (1975/1990=5) if eastwest==2, gen(cohort_e1) 
recode yborn (1898/1930=1) (1931/1945=2) (1946/1960=3) (1961/1974=4) (1975/1990=5) (1991/2002=6) if eastwest==2, gen(cohort_e2) 

keep age yborn year sex rp01 rd01 eastwest dh04 german wghtpew wghtht wghthew wghthtew cohort_w1 cohort_w2 cohort_e1 cohort_e2 coh5

save "$datapath\c21.dta", replace 


**************
*** Append ***
**************

use "$datapath\c8218.dta", clear

append using "$datapath\c21.dta"


********************
*** APC Analysis ***
********************

**************************
*** A) Western Germany ***
**************************

tab rd01
tab rd01, nolabel
recode rd01 (-42=.) (-9=.) (-7=.)
recode rd01 (1/5=1) (6=0), gen(churchm)

gen miss = 0
replace miss = 1 if rd01 == 5

tab age, nolabel
recode age (-32=.)
gen agec_w = age - 47.5
gen ageq_w = agec_w*agec_w
gen ageq = age*age

recode age (18/22=1) (23/27=2) (28/32=3) (33/37=4) (38/42=5) (43/47=6) (48/52=7) (53/57=8) (58/62=9) (63/67=10) (68/72=11) (73/77=12) (78/82=13) ///
(83/102=14), gen(age_cat) 

tab sex 
tab sex, nolabel
recode sex (1=1) (2=0) (else=.), gen(male)

gen year2 = year-1980

recode german (1=0) (2=0) (3=1) (-32=.), gen(ndh)

* Model fit

* AK
reg churchm age ageq i.coh5 if eastwest == 1 & miss == 0 & ndh == 0
estat ic
* 37402 / 37579

* PK
reg churchm i.coh5 year if eastwest == 1 & miss == 0 & ndh == 0
estat ic
* 37599 / 37767

* APK
reg churchm age ageq i.coh5 year if eastwest == 1 & miss == 0 & ndh == 0
estat ic
* 37381 / 37567 (bester AIC/BIC)

* HAPC (Figures  3-5)

* a) without centered age
bayes, showreffects rseed(12345): mixed churchm agec_w ageq_w if ndh == 0 & miss == 0 & eastwest == 1 || _all: R.year || coh5:

* b) with centered age
bayes, showreffects rseed(12345): mixed churchm age ageq if ndh == 0 & miss == 0 & eastwest == 1 || _all: R.year || coh5:


* HAPC-FC (Figures 3-5)

* a) without centered age
bayes, showreffects rseed(12345): mixed churchm age ageq i.coh5 if eastwest == 1 & ndh == 0 & miss == 0 || year:

* b) with centered age
bayes, showreffects rseed(12345): mixed churchm agec_w ageq_w i.coh5 if eastwest == 1 & ndh == 0 & miss == 0 || year:

* c) Interaction cohort*age  

gen coh5_14 = coh5-14
gen agexc1 = age*coh5_14
gen agexc2 = ageq*coh5_14 

mixed churchm age ageq coh5_14 agexc1 agexc2 if eastwest == 1 & ndh == 0 & miss == 0 || year:

gen coh5_18 = coh5-18
gen agexc3 = age*coh5_18
gen agexc4 = ageq*coh5_18 

mixed churchm age ageq coh5_18 agexc3 agexc4 if eastwest == 1 & ndh == 0 & miss == 0 || year:

gen agec14 = age-33
mixed churchm agec14 b7.coh5 if eastwest == 1 & ndh == 0 & miss == 0 || year:

gen agec18 = age-22.2
mixed churchm agec18 b18.coh5 if eastwest == 1 & ndh == 0 & miss == 0 || year:


**************************
*** B) Eastern Germany ***
**************************

gen year3 = year-1990
recode year3 (-10/-1=.)

gen agec_o = age-49.8
gen ageq_o = agec_o*agec_o


* AK
reg churchm age i.coh5 if eastwest == 2 & miss == 0 & ndh == 0
estat ic
* 21945 / 22094 

* PK
reg churchm i.coh5 year if eastwest == 2 & miss == 0 & ndh == 0
estat ic
* 21946 / 22094

* APK
reg churchm age i.coh5 year if eastwest == 2 & miss == 0 & ndh == 0
estat ic
* 21935 / 22091 (bester AIC/BIC)

* HAPC (Figures 3-5)

* a) without age centered
bayes, showreffects rseed(12345): mixed churchm age if ndh == 0 & miss == 0 & eastwest == 2 || _all: R.year || coh5:

* b) with age centered
bayes, showreffects rseed(12345): mixed churchm agec_o if ndh == 0 & miss == 0 & eastwest == 2 || _all: R.year || coh5:

* HAPC-FC (Figures 3-5)

* a) without age centered
bayes, showreffects rseed(12345): mixed churchm age i.coh5 if eastwest == 2 & ndh == 0 & miss == 0 || year:

* b) with age centered
bayes, showreffects rseed(12345): mixed churchm agec_o i.coh5 if eastwest == 2 & ndh == 0 & miss == 0 || year:

* c) Interaction cohort*age

mixed churchm age i.coh5 agexc1 if eastwest == 2 & ndh == 0 & miss == 0 || year:
